get_uk_data: Get UK data - helper function to get data for a single valid area type
Description
UK data download helper. Code adapted from PHE Coronavirus API for R:
available at https://github.com/publichealthengland/coronavirus-dashboard-api-R-sdk
Usage
get_uk_data(filters, progress_bar = FALSE)
Arguments
filters
Query filters for UK data e.g. "areaType=nation"
progress_bar
Display a progress bar, useful for level 2 which takes a while to load
Value
A dataframe with all variables available in public UK data